'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactIntl = require('react-intl');

var _reactRouterDom = require('react-router-dom');

var _cspaceInput = require('cspace-input');

var _LoginForm = require('../../../styles/cspace-ui/LoginForm.css');

var _LoginForm2 = _interopRequireDefault(_LoginForm);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Button = _cspaceInput.components.Button,
    LineInput = _cspaceInput.components.LineInput,
    PasswordInput = _cspaceInput.components.PasswordInput;


var messages = (0, _reactIntl.defineMessages)({
  title: {
    'id': 'loginForm.title',
    'defaultMessage': 'Sign In'
  },
  prompt: {
    'id': 'loginForm.prompt',
    'defaultMessage': 'Please sign in to continue.'
  },
  pending: {
    'id': 'loginForm.pending',
    'defaultMessage': 'Signing in...'
  },
  success: {
    'id': 'loginForm.success',
    'defaultMessage': 'Sign in complete.'
  },
  error: {
    'id': 'loginForm.error',
    'defaultMessage': 'Sign in failed.'
  },
  badCredentialsError: {
    'id': 'loginForm.error.badCredentials',
    'defaultMessage': 'Sign in failed. Incorrect username/password.'
  },
  networkError: {
    'id': 'loginForm.error.networkError',
    'defaultMessage': 'Sign in failed. Unable to reach the CollectionSpace server.'
  },
  username: {
    'id': 'loginForm.username',
    'defaultMessage': 'Email'
  },
  password: {
    'id': 'loginForm.password',
    'defaultMessage': 'Password'
  },
  submit: {
    'id': 'loginForm.submit',
    'defaultMessage': 'Sign in'
  },
  forgotPassword: {
    'id': 'loginForm.forgotPassword',
    'defaultMessage': 'Forgot password'
  }
});

/**
 * Map client error descriptions to keys in the above messages object.
 */
var errorMessageMap = {
  'Bad credentials': 'badCredentialsError',
  'Network Error': 'networkError'
};

var contextTypes = {
  config: _propTypes2.default.object
};

var propTypes = {
  intl: _propTypes2.default.object.isRequired,
  isPending: _propTypes2.default.bool,
  username: _propTypes2.default.string,
  error: _propTypes2.default.object,
  login: _propTypes2.default.func,
  onSuccess: _propTypes2.default.func
};

var LoginForm = function (_Component) {
  _inherits(LoginForm, _Component);

  function LoginForm(props) {
    _classCallCheck(this, LoginForm);

    var _this = _possibleConstructorReturn(this, (LoginForm.__proto__ || Object.getPrototypeOf(LoginForm)).call(this, props));

    _this.handleSubmit = _this.handleSubmit.bind(_this);
    _this.handleUsernameChange = _this.handleUsernameChange.bind(_this);

    _this.state = {
      username: props.username
    };
    return _this;
  }

  _createClass(LoginForm, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      this.setState({
        username: nextProps.username
      });
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      var _props = this.props,
          onSuccess = _props.onSuccess,
          isPending = _props.isPending,
          error = _props.error;


      if (onSuccess) {
        var isSuccess = prevProps.isPending && !isPending && !error;

        if (isSuccess) {
          onSuccess();
        }
      }
    }
  }, {
    key: 'handleSubmit',
    value: function handleSubmit(event) {
      event.preventDefault();

      var login = this.props.login;
      var config = this.context.config;


      if (login) {
        var form = event.target;
        var username = form.username.value;
        var password = form.password.value;

        login(config, username, password);
      }
    }
  }, {
    key: 'handleUsernameChange',
    value: function handleUsernameChange(value) {
      this.setState({
        username: value
      });
    }
  }, {
    key: 'renderMessage',
    value: function renderMessage() {
      var _props2 = this.props,
          isPending = _props2.isPending,
          error = _props2.error,
          username = _props2.username;


      var messageKey = 'prompt';

      if (isPending) {
        messageKey = 'pending';
      } else if (error) {
        var desc = error.getIn(['response', 'data', 'error_description']);

        if (desc) {
          messageKey = errorMessageMap[desc];
        } else {
          messageKey = errorMessageMap[error.get('message')];
        }

        messageKey = messageKey || 'error';
      } else if (username) {
        messageKey = 'success';
      }

      return _react2.default.createElement(
        'p',
        null,
        _react2.default.createElement(_reactIntl.FormattedMessage, messages[messageKey])
      );
    }
  }, {
    key: 'renderForm',
    value: function renderForm() {
      var _props3 = this.props,
          intl = _props3.intl,
          isPending = _props3.isPending;


      if (isPending) {
        return null;
      }

      var username = this.state.username;


      return _react2.default.createElement(
        'form',
        { onSubmit: this.handleSubmit },
        _react2.default.createElement(LineInput, {
          autoComplete: 'username email',
          name: 'username',
          placeholder: intl.formatMessage(messages.username),
          type: 'text',
          value: username,
          onChange: this.handleUsernameChange
        }),
        _react2.default.createElement(PasswordInput, {
          autoComplete: 'current-password',
          name: 'password',
          placeholder: intl.formatMessage(messages.password)
        }),
        _react2.default.createElement(
          'div',
          null,
          _react2.default.createElement(
            Button,
            { type: 'submit' },
            _react2.default.createElement(_reactIntl.FormattedMessage, messages.submit)
          ),
          _react2.default.createElement(
            _reactRouterDom.Link,
            {
              to: {
                pathname: '/resetpw',
                state: {
                  username: username
                }
              }
            },
            _react2.default.createElement(_reactIntl.FormattedMessage, messages.forgotPassword)
          )
        )
      );
    }
  }, {
    key: 'render',
    value: function render() {
      return _react2.default.createElement(
        'div',
        { className: _LoginForm2.default.common },
        _react2.default.createElement(
          'h2',
          null,
          _react2.default.createElement(_reactIntl.FormattedMessage, messages.title)
        ),
        this.renderMessage(),
        this.renderForm()
      );
    }
  }]);

  return LoginForm;
}(_react.Component);

LoginForm.contextTypes = contextTypes;
LoginForm.propTypes = propTypes;

exports.default = (0, _reactIntl.injectIntl)(LoginForm);